<nav class="nav bg-light">
    <li class="nav-item">
      <a class="nav-link" href="" title="Category home">
        <button type="button" class="btn btn-info">
            f4gf
        </button>
      </a>
    </li>
    <li class="nav-item">
      <a class="nav-link" href="" title=" ">
        <button type="button" class="btn btn-info">
            5tg
        </button>
      </a>
    </li>
    <li class="nav-item">
      <a class="nav-link" href="" title=" ">
        <button type="button" class="btn btn-info">
            5g
        </button>
      </a>
    </li>
    
</nav>