"""empty message

Revision ID: acaae477cfef
Revises: 23a30e62194e
Create Date: 2020-10-08 09:03:05.065918

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'acaae477cfef'
down_revision = '23a30e62194e'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('people', sa.Column('is_manufacturer', sa.Boolean(), nullable=True))
    op.add_column('people', sa.Column('manufacturer_address', sa.String(length=200), nullable=True))
    op.add_column('people', sa.Column('manufacturer_name', sa.String(length=100), nullable=True))
    op.add_column('people', sa.Column('manufacturer_phone', sa.Integer(), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('people', 'manufacturer_phone')
    op.drop_column('people', 'manufacturer_name')
    op.drop_column('people', 'manufacturer_address')
    op.drop_column('people', 'is_manufacturer')
    # ### end Alembic commands ###
