
{% extends "base/main_base.html" %}

{% set active_page = "contact" %}
{% block pagehead %}
    <title>{{active_page.capitalize()}}</title>

{% endblock %}



{% block content %}

<form action="{{url_for('contact.validate_message')}}" method="POST">

<div class="form-field">
{{ form.name.label }} <br>
<div class="input-group mb-3">
    <div class="input-group-prepend">
        <span class="input-group-text"><i class="fa fa-info"></i></span>
    </div>
    {{ form.name }}
</div>
</div>

<div class="form-field">
{{ form.email.label }} <br>
<div class="input-group mb-3">
    <div class="input-group-prepend">
        <span class="input-group-text"><i class="fa fa-envelope"></i></span>
    </div>
    {{ form.email }}
</div>
</div>

<div class="form-field">
{{ form.message.label }} <br>
<div class="input-group mb-3">
    <div class="input-group-prepend">
        <span class="input-group-text"><i class="fa fa-pencil-alt"></i></span>
    </div>
    {{ form.message }}
</div>
</div>
<br>
<button type="submit" class="btn btn-success">Submit</button>
<input type="hidden" name="csrf_token" value="{{csrf_token()}}">
</form>
<br>
{% endblock %}










